/****************************************************************************
** Meta object code from reading C++ file 'weatherforecast.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/weather/weatherforecast.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'weatherforecast.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15WeatherForecastE_t {};
} // unnamed namespace

template <> constexpr inline auto WeatherForecast::qt_create_metaobjectdata<qt_meta_tag_ZN15WeatherForecastE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WeatherForecast",
        "QML.Element",
        "weatherForecast",
        "valid",
        "minimumTemperature",
        "maximumTemperature",
        "precipitation",
        "windSpeed",
        "symbolIconName",
        "range",
        "isSevere",
        "SymbolType",
        "SymbolFlag",
        "None",
        "Clear",
        "LightClouds",
        "Clouds",
        "LightRain",
        "Rain",
        "LightSnow",
        "Snow",
        "Hail",
        "ThunderStorm",
        "Fog",
        "Wind"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minimumTemperature'
        QtMocHelpers::PropertyData<float>(4, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumTemperature'
        QtMocHelpers::PropertyData<float>(5, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'precipitation'
        QtMocHelpers::PropertyData<float>(6, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windSpeed'
        QtMocHelpers::PropertyData<float>(7, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'symbolIconName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'range'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isSevere'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'SymbolType'
        QtMocHelpers::EnumData<SymbolType>(11, 12, QMC::EnumIsFlag).add({
            {   13, SymbolFlag::None },
            {   14, SymbolFlag::Clear },
            {   15, SymbolFlag::LightClouds },
            {   16, SymbolFlag::Clouds },
            {   17, SymbolFlag::LightRain },
            {   18, SymbolFlag::Rain },
            {   19, SymbolFlag::LightSnow },
            {   20, SymbolFlag::Snow },
            {   21, SymbolFlag::Hail },
            {   22, SymbolFlag::ThunderStorm },
            {   23, SymbolFlag::Fog },
            {   24, SymbolFlag::Wind },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<WeatherForecast, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject WeatherForecast::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WeatherForecastE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15WeatherForecastE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15WeatherForecastE_t>.metaTypes,
    nullptr
} };

void WeatherForecast::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<WeatherForecast *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->minimumTemperature(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->maximumTemperature(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->precipitation(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->windSpeed(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->symbolIconName(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->range(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSevere(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
