/****************************************************************************
** Meta object code from reading C++ file 'tripgroupcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/tripgroupcontroller.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tripgroupcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TripGroupControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupController::qt_create_metaobjectdata<qt_meta_tag_ZN19TripGroupControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupController",
        "QML.Element",
        "auto",
        "setupChanged",
        "",
        "tripGroupChanged",
        "adjacencyChanged",
        "weatherForecastChanged",
        "locationInfoChanged",
        "tripGroupContentChanged",
        "tripEnded",
        "tripGroupId",
        "tripGroupModel",
        "TripGroupModel*",
        "weatherForecastManager",
        "WeatherForecastManager*",
        "homeCountryIsoCode",
        "homeCurrency",
        "convertCurrency",
        "weatherForecast",
        "WeatherForecast",
        "locationInformation",
        "QVariantList",
        "currencies",
        "transferManager",
        "TransferManager*",
        "canMerge",
        "canSplit",
        "totalDistance",
        "totalCO2Emission",
        "totalCost",
        "Price",
        "isPastTrip"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tripGroupChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adjacencyChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weatherForecastChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locationInfoChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tripGroupContentChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tripEnded'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tripGroupId'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'tripGroupModel'
        QtMocHelpers::PropertyData<TripGroupModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'weatherForecastManager'
        QtMocHelpers::PropertyData<WeatherForecastManager*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'homeCountryIsoCode'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'homeCurrency'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'convertCurrency'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'weatherForecast'
        QtMocHelpers::PropertyData<WeatherForecast>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'locationInformation'
        QtMocHelpers::PropertyData<QVariantList>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'currencies'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'transferManager'
        QtMocHelpers::PropertyData<TransferManager*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'canMerge'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'canSplit'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'totalDistance'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags, 5),
        // property 'totalCO2Emission'
        QtMocHelpers::PropertyData<double>(29, QMetaType::Double, QMC::DefaultPropertyFlags, 5),
        // property 'totalCost'
        QtMocHelpers::PropertyData<Price>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'isPastTrip'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TripGroupController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TripGroupController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TripGroupControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TripGroupControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TripGroupControllerE_t>.metaTypes,
    nullptr
} };

void TripGroupController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TripGroupController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupChanged(); break;
        case 1: _t->tripGroupChanged(); break;
        case 2: _t->adjacencyChanged(); break;
        case 3: _t->weatherForecastChanged(); break;
        case 4: _t->locationInfoChanged(); break;
        case 5: _t->tripGroupContentChanged(); break;
        case 6: _t->tripEnded(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::setupChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::tripGroupChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::adjacencyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::weatherForecastChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::locationInfoChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::tripGroupContentChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupController::*)()>(_a, &TripGroupController::tripEnded, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TransferManager* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TripGroupModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< WeatherForecast >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< WeatherForecastManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_tgId; break;
        case 1: *reinterpret_cast<TripGroupModel**>(_v) = _t->m_tripGroupModel; break;
        case 2: *reinterpret_cast<WeatherForecastManager**>(_v) = _t->m_weatherMgr; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_homeCountry; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_homeCurrency; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_convertCurrency; break;
        case 6: *reinterpret_cast<WeatherForecast*>(_v) = _t->weatherForecast(); break;
        case 7: *reinterpret_cast<QVariantList*>(_v) = _t->locationInformation(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->currencies(); break;
        case 9: *reinterpret_cast<TransferManager**>(_v) = _t->m_tranferMgr; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->canMerge(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->canSplit(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->totalDistance(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->totalCO2Emission(); break;
        case 14: *reinterpret_cast<Price*>(_v) = _t->totalCost(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isPastTrip(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_tgId, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->tripGroupChanged();
            break;
        case 1: _t->setTripGroupModel(*reinterpret_cast<TripGroupModel**>(_v)); break;
        case 2: _t->setWeatherForecastManager(*reinterpret_cast<WeatherForecastManager**>(_v)); break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_homeCountry, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->locationInfoChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_homeCurrency, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->locationInfoChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_convertCurrency, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->tripGroupContentChanged();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_tranferMgr, *reinterpret_cast<TransferManager**>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TripGroupController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TripGroupController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TripGroupControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TripGroupController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void TripGroupController::setupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TripGroupController::tripGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TripGroupController::adjacencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TripGroupController::weatherForecastChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TripGroupController::locationInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TripGroupController::tripGroupContentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TripGroupController::tripEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
