/****************************************************************************
** Meta object code from reading C++ file 'factory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/factory.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'factory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7FactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto Factory::qt_create_metaobjectdata<qt_meta_tag_ZN7FactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Factory",
        "makeFlightReservation",
        "QVariant",
        "",
        "makeBoatReservation",
        "makeBusReservation",
        "makeTrainReservation",
        "makeEventReservation",
        "makeFoodEstablishmentReservation",
        "makeLodgingReservation",
        "makePerson",
        "makePlace",
        "makeProgramMembership",
        "makeTicket"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'makeFlightReservation'
        QtMocHelpers::MethodData<QVariant()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeBoatReservation'
        QtMocHelpers::MethodData<QVariant()>(4, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeBusReservation'
        QtMocHelpers::MethodData<QVariant()>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeTrainReservation'
        QtMocHelpers::MethodData<QVariant()>(6, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeEventReservation'
        QtMocHelpers::MethodData<QVariant()>(7, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeFoodEstablishmentReservation'
        QtMocHelpers::MethodData<QVariant()>(8, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeLodgingReservation'
        QtMocHelpers::MethodData<QVariant()>(9, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makePerson'
        QtMocHelpers::MethodData<QVariant()>(10, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makePlace'
        QtMocHelpers::MethodData<QVariant()>(11, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeProgramMembership'
        QtMocHelpers::MethodData<QVariant()>(12, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Method 'makeTicket'
        QtMocHelpers::MethodData<QVariant()>(13, 3, QMC::AccessPublic, 0x80000000 | 2),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Factory, qt_meta_tag_ZN7FactoryE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Factory::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7FactoryE_t>.metaTypes,
    nullptr
} };

void Factory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Factory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QVariant _r = _t->makeFlightReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 1: { QVariant _r = _t->makeBoatReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariant _r = _t->makeBusReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariant _r = _t->makeTrainReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariant _r = _t->makeEventReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariant _r = _t->makeFoodEstablishmentReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariant _r = _t->makeLodgingReservation();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariant _r = _t->makePerson();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariant _r = _t->makePlace();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariant _r = _t->makeProgramMembership();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariant _r = _t->makeTicket();
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
QT_WARNING_POP
