/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<applicationcontroller.h>)
#  include <applicationcontroller.h>
#endif
#if __has_include(<clipboard.h>)
#  include <clipboard.h>
#endif
#if __has_include(<countrysubdivisionmodel.h>)
#  include <countrysubdivisionmodel.h>
#endif
#if __has_include(<documentsmodel.h>)
#  include <documentsmodel.h>
#endif
#if __has_include(<healthcertificatemanager.h>)
#  include <healthcertificatemanager.h>
#endif
#if __has_include(<journeysectionmodel.h>)
#  include <journeysectionmodel.h>
#endif
#if __has_include(<kdeconnect.h>)
#  include <kdeconnect.h>
#endif
#if __has_include(<locationinformation.h>)
#  include <locationinformation.h>
#endif
#if __has_include(<onlineticketimporter.h>)
#  include <onlineticketimporter.h>
#endif
#if __has_include(<permissionmanager.h>)
#  include <permissionmanager.h>
#endif
#if __has_include(<qmlsingletons.h>)
#  include <qmlsingletons.h>
#endif
#if __has_include(<statisticsmodel.h>)
#  include <statisticsmodel.h>
#endif
#if __has_include(<statisticstimerangemodel.h>)
#  include <statisticstimerangemodel.h>
#endif
#if __has_include(<tickettokenmodel.h>)
#  include <tickettokenmodel.h>
#endif
#if __has_include(<timelinedelegatecontroller.h>)
#  include <timelinedelegatecontroller.h>
#endif
#if __has_include(<timelineelement.h>)
#  include <timelineelement.h>
#endif
#if __has_include(<timelinemodel.h>)
#  include <timelinemodel.h>
#endif
#if __has_include(<timelinesectiondelegatecontroller.h>)
#  include <timelinesectiondelegatecontroller.h>
#endif
#if __has_include(<transfer.h>)
#  include <transfer.h>
#endif
#if __has_include(<transferdelegatecontroller.h>)
#  include <transferdelegatecontroller.h>
#endif
#if __has_include(<tripgroupcontroller.h>)
#  include <tripgroupcontroller.h>
#endif
#if __has_include(<tripgroupfilterproxymodel.h>)
#  include <tripgroupfilterproxymodel.h>
#endif
#if __has_include(<tripgrouplocationmodel.h>)
#  include <tripgrouplocationmodel.h>
#endif
#if __has_include(<tripgroupmapmodel.h>)
#  include <tripgroupmapmodel.h>
#endif
#if __has_include(<tripgroupsplitmodel.h>)
#  include <tripgroupsplitmodel.h>
#endif
#if __has_include(<weatherforecastmodel.h>)
#  include <weatherforecastmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_itinerary()
{
    qmlRegisterModule("org.kde.itinerary", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ApplicationControllerForeign>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<Clipboard>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<CountrySubdivisionModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<DocumentManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<DocumentsModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<FavoriteLocationModelInstance>("org.kde.itinerary", 254);
    qmlRegisterEnum<FavoriteLocationModel::Role>("FavoriteLocationModel::Role");
    qmlRegisterTypesAndRevisions<HealthCertificateManager>("org.kde.itinerary", 254);
    qmlRegisterEnum<HealthCertificateManager::ExtraRoles>("HealthCertificateManager::ExtraRoles");
    qmlRegisterTypesAndRevisions<ImportControllerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<JourneySectionModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<KDEConnectDeviceModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<LiveDataManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<LocationInformation>("org.kde.itinerary", 254);
    qmlRegisterEnum<LocationInformation::PowerPlugCompatibility>("LocationInformation::PowerPlugCompatibility");
    QMetaType::fromType<LocationInformationDerived>().id();
    qmlRegisterNamespaceAndRevisions(&LocationInformationDerived::staticMetaObject, "org.kde.itinerary", 254, nullptr, &LocationInformationDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<MapDownloadManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<MatrixControllerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<OnlineTicketImporter>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<PassManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterEnum<PassManager::Roles>("PassManager::Roles");
    qmlRegisterEnum<PassManager::PassType>("PassManager::PassType");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &Permission::staticMetaObject;},
            "Permission");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&Permission::staticMetaObject, "org.kde.itinerary", 254, nullptr, &Permission::staticMetaObject, nullptr);
    qmlRegisterEnum<Permission::Permission>("Permission::Permission");
    qmlRegisterTypesAndRevisions<PkPassManagerInstance>("org.kde.itinerary", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<ReservationManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<SettingsInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<StatisticsItem>("org.kde.itinerary", 254);
    qmlRegisterEnum<StatisticsItem::Trend>("StatisticsItem::Trend");
    QMetaType::fromType<StatisticsItemDerived>().id();
    qmlRegisterNamespaceAndRevisions(&StatisticsItemDerived::staticMetaObject, "org.kde.itinerary", 254, nullptr, &StatisticsItemDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<StatisticsModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<StatisticsTimeRangeModel>("org.kde.itinerary", 254);
    qmlRegisterEnum<StatisticsTimeRangeModel::CustomRoles>("StatisticsTimeRangeModel::CustomRoles");
    qmlRegisterTypesAndRevisions<TicketTokenModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TimelineDelegateController>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TimelineElement>("org.kde.itinerary", 254);
    qmlRegisterEnum<TimelineElement::ElementType>("TimelineElement::ElementType");
    qmlRegisterEnum<TimelineElement::RangeType>("TimelineElement::RangeType");
    QMetaType::fromType<TimelineElementDerived>().id();
    qmlRegisterNamespaceAndRevisions(&TimelineElementDerived::staticMetaObject, "org.kde.itinerary", 254, nullptr, &TimelineElementDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<TimelineModel>("org.kde.itinerary", 254);
    qmlRegisterEnum<TimelineModel::Role>("TimelineModel::Role");
    qmlRegisterTypesAndRevisions<TimelineSectionDelegateController>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TraewellingControllerInstance>("org.kde.itinerary", 254);
    qmlRegisterEnum<TraewellingController::UploadStatus>("TraewellingController::UploadStatus");
    qmlRegisterTypesAndRevisions<Transfer>("org.kde.itinerary", 254);
    qmlRegisterEnum<Transfer::Alignment>("Transfer::Alignment");
    qmlRegisterEnum<Transfer::State>("Transfer::State");
    qmlRegisterEnum<Transfer::FloatingLocationType>("Transfer::FloatingLocationType");
    qmlRegisterTypesAndRevisions<TransferDelegateController>("org.kde.itinerary", 254);
    QMetaType::fromType<TransferDerived>().id();
    qmlRegisterNamespaceAndRevisions(&TransferDerived::staticMetaObject, "org.kde.itinerary", 254, nullptr, &TransferDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<TransferManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TripGroupController>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TripGroupFilterProxyModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TripGroupLocationModel>("org.kde.itinerary", 254);
    qmlRegisterEnum<TripGroupLocationModel::Role>("TripGroupLocationModel::Role");
    qmlRegisterTypesAndRevisions<TripGroupManagerInstance>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TripGroupMapModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<TripGroupModelInstance>("org.kde.itinerary", 254);
    qmlRegisterEnum<TripGroupModel::Position>("TripGroupModel::Position");
    qmlRegisterTypesAndRevisions<TripGroupSplitModel>("org.kde.itinerary", 254);
    qmlRegisterTypesAndRevisions<WeatherForecastModel>("org.kde.itinerary", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.itinerary", 254, 254);
}

static const QQmlModuleRegistration orgkdeitineraryRegistration("org.kde.itinerary", qml_register_types_org_kde_itinerary);
