/****************************************************************************
** Meta object code from reading C++ file 'timelinemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/timelinemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TimelineModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineModel::qt_create_metaobjectdata<qt_meta_tag_ZN13TimelineModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineModel",
        "QML.Element",
        "auto",
        "setupChanged",
        "",
        "todayRowChanged",
        "tripGroupIdChanged",
        "initialLocationChanged",
        "todayRow",
        "reservationManager",
        "ReservationManager*",
        "transferManager",
        "TransferManager*",
        "tripGroupManager",
        "TripGroupManager*",
        "weatherForecastManager",
        "WeatherForecastManager*",
        "homeCountryIsoCode",
        "tripGroupId",
        "initialLocation",
        "QVariant",
        "Role",
        "SectionHeaderRole",
        "BatchIdRole",
        "ElementTypeRole",
        "TodayEmptyRole",
        "IsTodayRole",
        "ElementRangeRole",
        "LocationInformationRole",
        "WeatherForecastRole",
        "ReservationsRole",
        "TransferRole",
        "StartDateTimeRole",
        "EndDateTimeRole",
        "IsTimeboxedRole",
        "IsCanceledRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todayRowChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tripGroupIdChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialLocationChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'todayRow'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'reservationManager'
        QtMocHelpers::PropertyData<ReservationManager*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'transferManager'
        QtMocHelpers::PropertyData<TransferManager*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'tripGroupManager'
        QtMocHelpers::PropertyData<TripGroupManager*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'weatherForecastManager'
        QtMocHelpers::PropertyData<WeatherForecastManager*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'homeCountryIsoCode'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'tripGroupId'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'initialLocation'
        QtMocHelpers::PropertyData<QVariant>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(21, 21, QMC::EnumFlags{}).add({
            {   22, Role::SectionHeaderRole },
            {   23, Role::BatchIdRole },
            {   24, Role::ElementTypeRole },
            {   25, Role::TodayEmptyRole },
            {   26, Role::IsTodayRole },
            {   27, Role::ElementRangeRole },
            {   28, Role::LocationInformationRole },
            {   29, Role::WeatherForecastRole },
            {   30, Role::ReservationsRole },
            {   31, Role::TransferRole },
            {   32, Role::StartDateTimeRole },
            {   33, Role::EndDateTimeRole },
            {   34, Role::IsTimeboxedRole },
            {   35, Role::IsCanceledRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TimelineModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TimelineModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TimelineModelE_t>.metaTypes,
    nullptr
} };

void TimelineModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupChanged(); break;
        case 1: _t->todayRowChanged(); break;
        case 2: _t->tripGroupIdChanged(); break;
        case 3: _t->initialLocationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::setupChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::todayRowChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::tripGroupIdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::initialLocationChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->todayRow(); break;
        case 1: *reinterpret_cast<ReservationManager**>(_v) = _t->m_resMgr; break;
        case 2: *reinterpret_cast<TransferManager**>(_v) = _t->m_transferManager; break;
        case 3: *reinterpret_cast<TripGroupManager**>(_v) = _t->tripGroupManager(); break;
        case 4: *reinterpret_cast<WeatherForecastManager**>(_v) = _t->m_weatherMgr; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_homeCountry; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_tripGroupId; break;
        case 7: *reinterpret_cast<QVariant*>(_v) = _t->m_initialLocation; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setReservationManager(*reinterpret_cast<ReservationManager**>(_v)); break;
        case 2: _t->setTransferManager(*reinterpret_cast<TransferManager**>(_v)); break;
        case 3: _t->setTripGroupManager(*reinterpret_cast<TripGroupManager**>(_v)); break;
        case 4: _t->setWeatherForecastManager(*reinterpret_cast<WeatherForecastManager**>(_v)); break;
        case 5: _t->setHomeCountryIsoCode(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setTripGroupId(*reinterpret_cast<QString*>(_v)); break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_initialLocation, *reinterpret_cast<QVariant*>(_v)))
                Q_EMIT _t->initialLocationChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TimelineModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int TimelineModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void TimelineModel::setupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineModel::todayRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineModel::tripGroupIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TimelineModel::initialLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
