/****************************************************************************
** Meta object code from reading C++ file 'applicationcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/applicationcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applicationcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ApplicationControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto ApplicationController::qt_create_metaobjectdata<qt_meta_tag_ZN21ApplicationControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ApplicationController",
        "infoMessage",
        "",
        "msg",
        "openPageRequested",
        "page",
        "QVariantMap",
        "properties",
        "editNewHotelReservation",
        "QVariant",
        "res",
        "editNewRestaurantReservation",
        "editNewEventReservation",
        "contextTripGroupIdChanged",
        "reloadSettings",
        "commitImport",
        "ImportController*",
        "importController",
        "addNewReservation",
        "tgId",
        "exportToFile",
        "QUrl",
        "url",
        "exportTripToFile",
        "tripGroupId",
        "exportTripToKDEConnect",
        "deviceId",
        "exportTripToGpx",
        "exportBatchToFile",
        "batchId",
        "exportBatchToKDEConnect",
        "exportBatchToGpx",
        "exportPassToFile",
        "passId",
        "exportPassToKDEConnect",
        "exportPkPassToFile",
        "addDocumentToReservation",
        "removeDocumentFromReservation",
        "docId",
        "addDocumentToPass",
        "removeDocumentFromPass",
        "openDocument",
        "version",
        "extractorCapabilities",
        "aboutData",
        "userAgent",
        "contextTripGroupId",
        "hasHealthCertificateSupport",
        "healthCertificateManager",
        "HealthCertificateManager*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'openPageRequested'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'editNewHotelReservation'
        QtMocHelpers::SignalData<void(const QVariant &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'editNewRestaurantReservation'
        QtMocHelpers::SignalData<void(const QVariant &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'editNewEventReservation'
        QtMocHelpers::SignalData<void(const QVariant &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'contextTripGroupIdChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadSettings'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'commitImport'
        QtMocHelpers::MethodData<void(ImportController *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'addNewReservation'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 19 },
        }}),
        // Method 'exportToFile'
        QtMocHelpers::MethodData<void(const QUrl &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportTripToFile'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportTripToKDEConnect'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 26 },
        }}),
        // Method 'exportTripToGpx'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportBatchToFile'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportBatchToKDEConnect'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 26 },
        }}),
        // Method 'exportBatchToGpx'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportPassToFile'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'exportPassToKDEConnect'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 26 },
        }}),
        // Method 'exportPkPassToFile'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'addDocumentToReservation'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'removeDocumentFromReservation'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 38 },
        }}),
        // Method 'addDocumentToPass'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'removeDocumentFromPass'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 38 },
        }}),
        // Method 'openDocument'
        QtMocHelpers::MethodData<void(const QUrl &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'extractorCapabilities'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'aboutData'
        QtMocHelpers::PropertyData<QVariant>(44, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'userAgent'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'contextTripGroupId'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'hasHealthCertificateSupport'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'healthCertificateManager'
        QtMocHelpers::PropertyData<HealthCertificateManager*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ApplicationController, qt_meta_tag_ZN21ApplicationControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ApplicationController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ApplicationControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ApplicationControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ApplicationControllerE_t>.metaTypes,
    nullptr
} };

void ApplicationController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ApplicationController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openPageRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 2: _t->editNewHotelReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 3: _t->editNewRestaurantReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 4: _t->editNewEventReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 5: _t->contextTripGroupIdChanged(); break;
        case 6: _t->reloadSettings(); break;
        case 7: _t->commitImport((*reinterpret_cast<std::add_pointer_t<ImportController*>>(_a[1]))); break;
        case 8: { QString _r = _t->addNewReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->exportToFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->exportTripToFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 11: _t->exportTripToKDEConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->exportTripToGpx((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 13: _t->exportBatchToFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 14: _t->exportBatchToKDEConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->exportBatchToGpx((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 16: _t->exportPassToFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 17: _t->exportPassToKDEConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->exportPkPassToFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 19: _t->addDocumentToReservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 20: _t->removeDocumentFromReservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->addDocumentToPass((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 22: _t->removeDocumentFromPass((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)(const QString & )>(_a, &ApplicationController::infoMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)(const QString & , const QVariantMap & )>(_a, &ApplicationController::openPageRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)(const QVariant & )>(_a, &ApplicationController::editNewHotelReservation, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)(const QVariant & )>(_a, &ApplicationController::editNewRestaurantReservation, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)(const QVariant & )>(_a, &ApplicationController::editNewEventReservation, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)()>(_a, &ApplicationController::contextTripGroupIdChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ApplicationController::*)()>(_a, &ApplicationController::reloadSettings, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->applicationVersion(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->extractorCapabilities(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->aboutData(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->userAgent(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_contextTripGroupId; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasHealthCertificateSupport(); break;
        case 6: *reinterpret_cast<HealthCertificateManager**>(_v) = _t->healthCertificateManager(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setContextTripGroupId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ApplicationController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ApplicationController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ApplicationControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ApplicationController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ApplicationController::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ApplicationController::openPageRequested(const QString & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ApplicationController::editNewHotelReservation(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ApplicationController::editNewRestaurantReservation(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ApplicationController::editNewEventReservation(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ApplicationController::contextTripGroupIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ApplicationController::reloadSettings()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN28ApplicationControllerForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto ApplicationControllerForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28ApplicationControllerForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ApplicationControllerForeign",
        "QML.Foreign",
        "ApplicationController",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<ApplicationControllerForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ApplicationControllerForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28ApplicationControllerForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28ApplicationControllerForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28ApplicationControllerForeignE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
