/****************************************************************************
** Meta object code from reading C++ file 'transfermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/transfermanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TransferManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferManager::qt_create_metaobjectdata<qt_meta_tag_ZN15TransferManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferManager",
        "transferAdded",
        "",
        "Transfer",
        "transfer",
        "transferChanged",
        "transferRemoved",
        "resId",
        "Transfer::Alignment",
        "alignment",
        "homeLocationChanged",
        "setJourneyForTransfer",
        "KPublicTransport::Journey",
        "journey",
        "setFavoriteLocationForTransfer",
        "FavoriteLocation",
        "favoriteLocation",
        "discardTransfer",
        "canAddTransfer",
        "addTransfer",
        "journeyRequestForTransfer",
        "KPublicTransport::JourneyRequest"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transferAdded'
        QtMocHelpers::SignalData<void(const Transfer &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'transferChanged'
        QtMocHelpers::SignalData<void(const Transfer &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'transferRemoved'
        QtMocHelpers::SignalData<void(const QString &, Transfer::Alignment)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'homeLocationChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setJourneyForTransfer'
        QtMocHelpers::MethodData<void(Transfer, const KPublicTransport::Journey &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'setFavoriteLocationForTransfer'
        QtMocHelpers::MethodData<Transfer(Transfer, const FavoriteLocation &)>(14, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'discardTransfer'
        QtMocHelpers::MethodData<void(Transfer)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'canAddTransfer'
        QtMocHelpers::MethodData<bool(const QString &, Transfer::Alignment) const>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Method 'addTransfer'
        QtMocHelpers::MethodData<Transfer(const QString &, Transfer::Alignment)>(19, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Method 'journeyRequestForTransfer'
        QtMocHelpers::MethodData<KPublicTransport::JourneyRequest(const Transfer &) const>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferManager, qt_meta_tag_ZN15TransferManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TransferManagerE_t>.metaTypes,
    nullptr
} };

void TransferManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transferAdded((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1]))); break;
        case 1: _t->transferChanged((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1]))); break;
        case 2: _t->transferRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Transfer::Alignment>>(_a[2]))); break;
        case 3: _t->homeLocationChanged(); break;
        case 4: _t->setJourneyForTransfer((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KPublicTransport::Journey>>(_a[2]))); break;
        case 5: { Transfer _r = _t->setFavoriteLocationForTransfer((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FavoriteLocation>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Transfer*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->discardTransfer((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1]))); break;
        case 7: { bool _r = _t->canAddTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Transfer::Alignment>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { Transfer _r = _t->addTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Transfer::Alignment>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Transfer*>(_a[0]) = std::move(_r); }  break;
        case 9: { KPublicTransport::JourneyRequest _r = _t->journeyRequestForTransfer((*reinterpret_cast<std::add_pointer_t<Transfer>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KPublicTransport::JourneyRequest*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::Journey >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Transfer >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(const Transfer & )>(_a, &TransferManager::transferAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(const Transfer & )>(_a, &TransferManager::transferChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)(const QString & , Transfer::Alignment )>(_a, &TransferManager::transferRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferManager::*)()>(_a, &TransferManager::homeLocationChanged, 3))
            return;
    }
}

const QMetaObject *TransferManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TransferManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TransferManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void TransferManager::transferAdded(const Transfer & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TransferManager::transferChanged(const Transfer & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TransferManager::transferRemoved(const QString & _t1, Transfer::Alignment _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TransferManager::homeLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
