/****************************************************************************
** Meta object code from reading C++ file 'statisticsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/statisticsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statisticsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14StatisticsItemE_t {};
} // unnamed namespace

template <> constexpr inline auto StatisticsItem::qt_create_metaobjectdata<qt_meta_tag_ZN14StatisticsItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatisticsItem",
        "QML.Element",
        "statisticsItem",
        "hasData",
        "label",
        "value",
        "trend",
        "Trend",
        "TrendUnknown",
        "TrendUp",
        "TrendDown",
        "TrendUnchanged"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasData'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'value'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'trend'
        QtMocHelpers::PropertyData<enum Trend>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Trend'
        QtMocHelpers::EnumData<enum Trend>(7, 7, QMC::EnumFlags{}).add({
            {    8, Trend::TrendUnknown },
            {    9, Trend::TrendUp },
            {   10, Trend::TrendDown },
            {   11, Trend::TrendUnchanged },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<StatisticsItem, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject StatisticsItem::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14StatisticsItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14StatisticsItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14StatisticsItemE_t>.metaTypes,
    nullptr
} };

void StatisticsItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<StatisticsItem *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_hasData; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_label; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_value; break;
        case 3: *reinterpret_cast<enum Trend*>(_v) = _t->m_trend; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN21StatisticsItemDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto StatisticsItemDerived::qt_create_metaobjectdata<qt_meta_tag_ZN21StatisticsItemDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatisticsItemDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StatisticsItemDerived, qt_meta_tag_ZN21StatisticsItemDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StatisticsItemDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<StatisticsItem>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21StatisticsItemDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21StatisticsItemDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21StatisticsItemDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN15StatisticsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto StatisticsModel::qt_create_metaobjectdata<qt_meta_tag_ZN15StatisticsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatisticsModel",
        "QML.Element",
        "auto",
        "setupChanged",
        "",
        "changed",
        "setTimeRange",
        "begin",
        "end",
        "totalCount",
        "StatisticsItem",
        "totalDistance",
        "totalNights",
        "totalCO2",
        "visitedCountries",
        "flightCount",
        "flightDistance",
        "flightCO2",
        "trainCount",
        "trainDistance",
        "trainCO2",
        "busCount",
        "busDistance",
        "busCO2",
        "carCount",
        "carDistance",
        "carCO2",
        "boatCount",
        "boatDistance",
        "boatCO2",
        "reservationManager",
        "ReservationManager*",
        "tripGroupManager",
        "TripGroupManager*",
        "transferManager",
        "TransferManager*",
        "distanceFormat",
        "KFormat::DistanceFormatOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setTimeRange'
        QtMocHelpers::MethodData<void(const QDate &, const QDate &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 7 }, { QMetaType::QDate, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'totalCount'
        QtMocHelpers::PropertyData<StatisticsItem>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'totalDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'totalNights'
        QtMocHelpers::PropertyData<StatisticsItem>(12, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'totalCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(13, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'visitedCountries'
        QtMocHelpers::PropertyData<StatisticsItem>(14, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'flightCount'
        QtMocHelpers::PropertyData<StatisticsItem>(15, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'flightDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(16, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'flightCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(17, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'trainCount'
        QtMocHelpers::PropertyData<StatisticsItem>(18, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'trainDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(19, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'trainCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(20, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'busCount'
        QtMocHelpers::PropertyData<StatisticsItem>(21, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'busDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(22, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'busCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(23, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'carCount'
        QtMocHelpers::PropertyData<StatisticsItem>(24, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'carDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(25, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'carCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(26, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'boatCount'
        QtMocHelpers::PropertyData<StatisticsItem>(27, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'boatDistance'
        QtMocHelpers::PropertyData<StatisticsItem>(28, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'boatCO2'
        QtMocHelpers::PropertyData<StatisticsItem>(29, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'reservationManager'
        QtMocHelpers::PropertyData<ReservationManager*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'tripGroupManager'
        QtMocHelpers::PropertyData<TripGroupManager*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'transferManager'
        QtMocHelpers::PropertyData<TransferManager*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'distanceFormat'
        QtMocHelpers::PropertyData<KFormat::DistanceFormatOptions>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<StatisticsModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15StatisticsModelE[] = {
    QMetaObject::SuperData::link<KFormat::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject StatisticsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StatisticsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StatisticsModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15StatisticsModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15StatisticsModelE_t>.metaTypes,
    nullptr
} };

void StatisticsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StatisticsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupChanged(); break;
        case 1: _t->changed(); break;
        case 2: _t->setTimeRange((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StatisticsModel::*)()>(_a, &StatisticsModel::setupChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StatisticsModel::*)()>(_a, &StatisticsModel::changed, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
        case 18:
        case 17:
        case 16:
        case 15:
        case 14:
        case 13:
        case 12:
        case 11:
        case 10:
        case 9:
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< StatisticsItem >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<StatisticsItem*>(_v) = _t->totalCount(); break;
        case 1: *reinterpret_cast<StatisticsItem*>(_v) = _t->totalDistance(); break;
        case 2: *reinterpret_cast<StatisticsItem*>(_v) = _t->totalNights(); break;
        case 3: *reinterpret_cast<StatisticsItem*>(_v) = _t->totalCO2(); break;
        case 4: *reinterpret_cast<StatisticsItem*>(_v) = _t->visitedCountries(); break;
        case 5: *reinterpret_cast<StatisticsItem*>(_v) = _t->flightCount(); break;
        case 6: *reinterpret_cast<StatisticsItem*>(_v) = _t->flightDistance(); break;
        case 7: *reinterpret_cast<StatisticsItem*>(_v) = _t->flightCO2(); break;
        case 8: *reinterpret_cast<StatisticsItem*>(_v) = _t->trainCount(); break;
        case 9: *reinterpret_cast<StatisticsItem*>(_v) = _t->trainDistance(); break;
        case 10: *reinterpret_cast<StatisticsItem*>(_v) = _t->trainCO2(); break;
        case 11: *reinterpret_cast<StatisticsItem*>(_v) = _t->busCount(); break;
        case 12: *reinterpret_cast<StatisticsItem*>(_v) = _t->busDistance(); break;
        case 13: *reinterpret_cast<StatisticsItem*>(_v) = _t->busCO2(); break;
        case 14: *reinterpret_cast<StatisticsItem*>(_v) = _t->carCount(); break;
        case 15: *reinterpret_cast<StatisticsItem*>(_v) = _t->carDistance(); break;
        case 16: *reinterpret_cast<StatisticsItem*>(_v) = _t->carCO2(); break;
        case 17: *reinterpret_cast<StatisticsItem*>(_v) = _t->boatCount(); break;
        case 18: *reinterpret_cast<StatisticsItem*>(_v) = _t->boatDistance(); break;
        case 19: *reinterpret_cast<StatisticsItem*>(_v) = _t->boatCO2(); break;
        case 20: *reinterpret_cast<ReservationManager**>(_v) = _t->m_resMgr; break;
        case 21: *reinterpret_cast<TripGroupManager**>(_v) = _t->m_tripGroupMgr; break;
        case 22: *reinterpret_cast<TransferManager**>(_v) = _t->m_transferMgr; break;
        case 23: *reinterpret_cast<KFormat::DistanceFormatOptions*>(_v) = _t->m_distanceFormat; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 20: _t->setReservationManager(*reinterpret_cast<ReservationManager**>(_v)); break;
        case 21: _t->setTripGroupManager(*reinterpret_cast<TripGroupManager**>(_v)); break;
        case 22: _t->setTransferManager(*reinterpret_cast<TransferManager**>(_v)); break;
        case 23:
            if (QtMocHelpers::setProperty(_t->m_distanceFormat, *reinterpret_cast<KFormat::DistanceFormatOptions*>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *StatisticsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatisticsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15StatisticsModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StatisticsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void StatisticsModel::setupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StatisticsModel::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN28StatisticsItemDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto StatisticsItemDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28StatisticsItemDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StatisticsItemDerivedForeign",
        "QML.Element",
        "StatisticsItem",
        "QML.Foreign",
        "StatisticsItemDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN28StatisticsItemDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN28StatisticsItemDerivedForeignE =
    StatisticsItemDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN28StatisticsItemDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN28StatisticsItemDerivedForeignE =
    qt_staticMetaObjectContent_ZN28StatisticsItemDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN28StatisticsItemDerivedForeignE =
    qt_staticMetaObjectContent_ZN28StatisticsItemDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject StatisticsItemDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN28StatisticsItemDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN28StatisticsItemDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN28StatisticsItemDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
