/****************************************************************************
** Meta object code from reading C++ file 'tripgroupmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/tripgroupmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tripgroupmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TripGroupManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupManager::qt_create_metaobjectdata<qt_meta_tag_ZN16TripGroupManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupManager",
        "tripGroupAdded",
        "",
        "id",
        "tripGroupChanged",
        "tripGroupAboutToBeRemoved",
        "tripGroupRemoved",
        "tripGroup",
        "TripGroup",
        "tripGroupIdForReservation",
        "resId",
        "isEmpty",
        "updateTripGroup",
        "groupId",
        "group",
        "removeReservationsInGroup",
        "guessName",
        "elements",
        "guessNameForReservations",
        "QVariantList",
        "merge",
        "tgId1",
        "tgId2",
        "newName",
        "createGroup",
        "name",
        "createEmptyGroup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tripGroupAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'tripGroupChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'tripGroupAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'tripGroupRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'tripGroup'
        QtMocHelpers::MethodData<TripGroup(const QString &) const>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'tripGroupIdForReservation'
        QtMocHelpers::MethodData<QString(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool() const>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'updateTripGroup'
        QtMocHelpers::MethodData<void(const QString &, const TripGroup &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 8, 14 },
        }}),
        // Method 'removeReservationsInGroup'
        QtMocHelpers::MethodData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'guessName'
        QtMocHelpers::MethodData<QString(const QStringList &) const>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Method 'guessNameForReservations'
        QtMocHelpers::MethodData<QString(const QVariantList &)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 19, 17 },
        }}),
        // Method 'merge'
        QtMocHelpers::MethodData<QString(const QString &, const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
        // Method 'createGroup'
        QtMocHelpers::MethodData<QString(const QStringList &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QStringList, 17 }, { QMetaType::QString, 25 },
        }}),
        // Method 'createEmptyGroup'
        QtMocHelpers::MethodData<QString(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TripGroupManager, qt_meta_tag_ZN16TripGroupManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TripGroupManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TripGroupManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TripGroupManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TripGroupManagerE_t>.metaTypes,
    nullptr
} };

void TripGroupManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TripGroupManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tripGroupAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->tripGroupChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->tripGroupAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->tripGroupRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { TripGroup _r = _t->tripGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<TripGroup*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->tripGroupIdForReservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isEmpty();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->updateTripGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TripGroup>>(_a[2]))); break;
        case 8: _t->removeReservationsInGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { QString _r = _t->guessName((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->guessNameForReservations((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->merge((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->createGroup((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->createEmptyGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TripGroupManager::*)(const QString & )>(_a, &TripGroupManager::tripGroupAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupManager::*)(const QString & )>(_a, &TripGroupManager::tripGroupChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupManager::*)(const QString & )>(_a, &TripGroupManager::tripGroupAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupManager::*)(const QString & )>(_a, &TripGroupManager::tripGroupRemoved, 3))
            return;
    }
}

const QMetaObject *TripGroupManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TripGroupManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TripGroupManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TripGroupManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void TripGroupManager::tripGroupAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TripGroupManager::tripGroupChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TripGroupManager::tripGroupAboutToBeRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TripGroupManager::tripGroupRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
