/****************************************************************************
** Meta object code from reading C++ file 'settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto Settings::qt_create_metaobjectdata<qt_meta_tag_ZN8SettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Settings",
        "weatherForecastEnabledChanged",
        "",
        "enabled",
        "homeCountryIsoCodeChanged",
        "isoCode",
        "forceMetricUnitsChanged",
        "force",
        "queryLiveDataChanged",
        "preloadMapDataChanged",
        "preload",
        "performCurrencyConversionChanged",
        "wikimediaOnlineContentEnabledChanged",
        "autoAddTransfersChanged",
        "autoAdd",
        "autoFillTransfersChanged",
        "autoFill",
        "showNotificationOnLockScreenChanged",
        "developmentModeChanged",
        "osmContributorModeChanged",
        "useFahrenheitChanged",
        "read",
        "QVariant",
        "key",
        "defaultValue",
        "write",
        "value",
        "readFileDialogFolder",
        "QUrl",
        "defaultUrl",
        "writeFileDialogFolder",
        "url",
        "weatherForecastEnabled",
        "homeCountryIsoCode",
        "forceMetricUnits",
        "queryLiveData",
        "preloadMapData",
        "performCurrencyConversion",
        "wikimediaOnlineContentEnabled",
        "autoAddTransfers",
        "autoFillTransfers",
        "showNotificationOnLockScreen",
        "osmContributorMode",
        "developmentMode",
        "useFahrenheit",
        "distanceFormat",
        "KFormat::DistanceFormatOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'weatherForecastEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'homeCountryIsoCodeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'forceMetricUnitsChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'queryLiveDataChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'preloadMapDataChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'performCurrencyConversionChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'wikimediaOnlineContentEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'autoAddTransfersChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'autoFillTransfersChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'showNotificationOnLockScreenChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'developmentModeChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'osmContributorModeChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'useFahrenheitChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'read'
        QtMocHelpers::MethodData<QVariant(const QString &, const QVariant &)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 22, 24 },
        }}),
        // Method 'write'
        QtMocHelpers::MethodData<void(const QString &, const QVariant &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 22, 26 },
        }}),
        // Method 'readFileDialogFolder'
        QtMocHelpers::MethodData<QUrl(const QString &, const QUrl &)>(27, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 28, 29 },
        }}),
        // Method 'writeFileDialogFolder'
        QtMocHelpers::MethodData<void(const QString &, const QUrl &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 28, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'weatherForecastEnabled'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'homeCountryIsoCode'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'forceMetricUnits'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'queryLiveData'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'preloadMapData'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'performCurrencyConversion'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'wikimediaOnlineContentEnabled'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'autoAddTransfers'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'autoFillTransfers'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'showNotificationOnLockScreen'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'osmContributorMode'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'developmentMode'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'useFahrenheit'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'distanceFormat'
        QtMocHelpers::PropertyData<KFormat::DistanceFormatOptions>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Settings, qt_meta_tag_ZN8SettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN8SettingsE[] = {
    QMetaObject::SuperData::link<KFormat::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Settings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN8SettingsE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SettingsE_t>.metaTypes,
    nullptr
} };

void Settings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Settings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->weatherForecastEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->homeCountryIsoCodeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->forceMetricUnitsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->queryLiveDataChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->preloadMapDataChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->performCurrencyConversionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->wikimediaOnlineContentEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->autoAddTransfersChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->autoFillTransfersChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->showNotificationOnLockScreenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->developmentModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->osmContributorModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->useFahrenheitChanged(); break;
        case 13: { QVariant _r = _t->read((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->write((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 15: { QUrl _r = _t->readFileDialogFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->writeFileDialogFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::weatherForecastEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(const QString & )>(_a, &Settings::homeCountryIsoCodeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::forceMetricUnitsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::queryLiveDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::preloadMapDataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::performCurrencyConversionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::wikimediaOnlineContentEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::autoAddTransfersChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::autoFillTransfersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::showNotificationOnLockScreenChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::developmentModeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)(bool )>(_a, &Settings::osmContributorModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Settings::*)()>(_a, &Settings::useFahrenheitChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->weatherForecastEnabled(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->homeCountryIsoCode(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->forceMetricUnits(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->queryLiveData(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->preloadMapData(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->performCurrencyConversion(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->wikimediaOnlineContentEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->autoAddTransfers(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->autoFillTransfers(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->showNotificationOnLockScreen(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_osmContributorMode; break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->developmentMode(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->useFahrenheit(); break;
        case 13: *reinterpret_cast<KFormat::DistanceFormatOptions*>(_v) = _t->distanceFormat(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWeatherForecastEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setHomeCountryIsoCode(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setForceMetricUnits(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setQueryLiveData(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setPreloadMapData(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPerformCurrencyConversion(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setWikimediaOnlineContentEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAutoAddTransfers(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setAutoFillTransfers(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setShowNotificationOnLockScreen(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setOsmContributorMode(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setDevelopmentMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Settings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Settings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Settings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void Settings::weatherForecastEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Settings::homeCountryIsoCodeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Settings::forceMetricUnitsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Settings::queryLiveDataChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Settings::preloadMapDataChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Settings::performCurrencyConversionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Settings::wikimediaOnlineContentEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Settings::autoAddTransfersChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Settings::autoFillTransfersChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Settings::showNotificationOnLockScreenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Settings::developmentModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Settings::osmContributorModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Settings::useFahrenheitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
