/****************************************************************************
** Meta object code from reading C++ file 'permissionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/permissionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'permissionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PermissionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PermissionManager::qt_create_metaobjectdata<qt_meta_tag_ZN17PermissionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PermissionManager",
        "checkPermission",
        "",
        "Permission::Permission",
        "permission",
        "requestPermission",
        "QJSValue",
        "callback"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'checkPermission'
        QtMocHelpers::MethodData<bool(Permission::Permission)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'requestPermission'
        QtMocHelpers::MethodData<void(Permission::Permission, QJSValue)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PermissionManager, qt_meta_tag_ZN17PermissionManagerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PermissionManager::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PermissionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PermissionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PermissionManagerE_t>.metaTypes,
    nullptr
} };

void PermissionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<PermissionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->checkPermission((*reinterpret_cast<std::add_pointer_t<Permission::Permission>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->requestPermission((*reinterpret_cast<std::add_pointer_t<Permission::Permission>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN10PermissionE_t {};
} // unnamed namespace

template <> constexpr inline auto Permission::qt_create_metaobjectdata<qt_meta_tag_ZN10PermissionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Permission",
        "QML.Element",
        "auto",
        "InvalidPermission",
        "ReadCalendar",
        "WriteCalendar",
        "Camera"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Permission'
        QtMocHelpers::EnumData<Permission>(0, 0, QMC::EnumFlags{}).add({
            {    3, Permission::InvalidPermission },
            {    4, Permission::ReadCalendar },
            {    5, Permission::WriteCalendar },
            {    6, Permission::Camera },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10PermissionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN10PermissionE =
    Permission::qt_create_metaobjectdata<qt_meta_tag_ZN10PermissionE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10PermissionE =
    qt_staticMetaObjectContent_ZN10PermissionE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10PermissionE =
    qt_staticMetaObjectContent_ZN10PermissionE.relocatingData;

Q_CONSTINIT const QMetaObject Permission::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10PermissionE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10PermissionE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10PermissionE.metaTypes,
    nullptr
} };

QT_WARNING_POP
