/****************************************************************************
** Meta object code from reading C++ file 'util.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/util.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'util.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4UtilE_t {};
} // unnamed namespace

template <> constexpr inline auto Util::qt_create_metaobjectdata<qt_meta_tag_ZN4UtilE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Util",
        "dateTimeStripTimezone",
        "",
        "QVariant",
        "obj",
        "propertyName",
        "setDateTimePreserveTimezone",
        "value",
        "isStartOfDay",
        "isRichText",
        "text",
        "textToHtml",
        "telephoneUrl",
        "phoneNumber",
        "emailUrl",
        "emailAddress",
        "sortModel",
        "model",
        "column",
        "Qt::SortOrder",
        "sortOrder",
        "isValidColor",
        "QColor",
        "color",
        "isLocationChange",
        "res",
        "isDarkImage",
        "QImage",
        "img",
        "toBase64",
        "data",
        "cacheLocation",
        "relativePath",
        "slugify",
        "input"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'dateTimeStripTimezone'
        QtMocHelpers::MethodData<QDateTime(const QVariant &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::QDateTime, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Method 'setDateTimePreserveTimezone'
        QtMocHelpers::MethodData<QVariant(const QVariant &, const QString &, QDateTime)>(6, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QDateTime, 7 },
        }}),
        // Method 'isStartOfDay'
        QtMocHelpers::MethodData<bool(const QVariant &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Method 'isRichText'
        QtMocHelpers::MethodData<bool(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'textToHtml'
        QtMocHelpers::MethodData<QString(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'telephoneUrl'
        QtMocHelpers::MethodData<QString(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'emailUrl'
        QtMocHelpers::MethodData<QString(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'sortModel'
        QtMocHelpers::MethodData<void(QObject *, int, Qt::SortOrder)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 17 }, { QMetaType::Int, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'isValidColor'
        QtMocHelpers::MethodData<bool(const QColor &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'isLocationChange'
        QtMocHelpers::MethodData<bool(const QVariant &)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 25 },
        }}),
        // Method 'isDarkImage'
        QtMocHelpers::MethodData<bool(const QImage &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Method 'toBase64'
        QtMocHelpers::MethodData<QString(const QByteArray &)>(29, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QByteArray, 30 },
        }}),
        // Method 'cacheLocation'
        QtMocHelpers::MethodData<QString(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 32 },
        }}),
        // Method 'slugify'
        QtMocHelpers::MethodData<QString(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Util, qt_meta_tag_ZN4UtilE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Util::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UtilE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UtilE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4UtilE_t>.metaTypes,
    nullptr
} };

void Util::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Util *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDateTime _r = _t->dateTimeStripTimezone((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 1: { QVariant _r = _t->setDateTimePreserveTimezone((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isStartOfDay((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->isRichText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->textToHtml((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->telephoneUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->emailUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->sortModel((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[3]))); break;
        case 8: { bool _r = _t->isValidColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->isLocationChange((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isDarkImage((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->toBase64((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->cacheLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->slugify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
QT_WARNING_POP
