/****************************************************************************
** Meta object code from reading C++ file 'transfer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/transfer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8TransferE_t {};
} // unnamed namespace

template <> constexpr inline auto Transfer::qt_create_metaobjectdata<qt_meta_tag_ZN8TransferE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Transfer",
        "QML.Element",
        "transfer",
        "alignment",
        "Alignment",
        "state",
        "State",
        "floatingLocationType",
        "FloatingLocationType",
        "from",
        "KPublicTransport::Location",
        "to",
        "fromName",
        "toName",
        "journey",
        "KPublicTransport::Journey",
        "reservationId",
        "anchorTime",
        "anchorTimeDelta",
        "journeyTime",
        "isReachable",
        "Before",
        "After",
        "UndefinedState",
        "Pending",
        "Selected",
        "Discarded",
        "Searching",
        "Reservation",
        "FavoriteLocation"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alignment'
        QtMocHelpers::PropertyData<enum Alignment>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'floatingLocationType'
        QtMocHelpers::PropertyData<enum FloatingLocationType>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'from'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'to'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'fromName'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'toName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'journey'
        QtMocHelpers::PropertyData<KPublicTransport::Journey>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'reservationId'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'anchorTime'
        QtMocHelpers::PropertyData<QDateTime>(17, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'anchorTimeDelta'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'journeyTime'
        QtMocHelpers::PropertyData<QDateTime>(19, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'isReachable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Alignment'
        QtMocHelpers::EnumData<enum Alignment>(4, 4, QMC::EnumFlags{}).add({
            {   21, Alignment::Before },
            {   22, Alignment::After },
        }),
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(6, 6, QMC::EnumFlags{}).add({
            {   23, State::UndefinedState },
            {   24, State::Pending },
            {   25, State::Selected },
            {   26, State::Discarded },
            {   27, State::Searching },
        }),
        // enum 'FloatingLocationType'
        QtMocHelpers::EnumData<enum FloatingLocationType>(8, 8, QMC::EnumFlags{}).add({
            {   28, FloatingLocationType::Reservation },
            {   29, FloatingLocationType::FavoriteLocation },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Transfer, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Transfer::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8TransferE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8TransferE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8TransferE_t>.metaTypes,
    nullptr
} };

void Transfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Transfer *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Journey >(); break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Alignment*>(_v) = _t->alignment(); break;
        case 1: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 2: *reinterpret_cast<enum FloatingLocationType*>(_v) = _t->floatingLocationType(); break;
        case 3: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->from(); break;
        case 4: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->to(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->fromName(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->toName(); break;
        case 7: *reinterpret_cast<KPublicTransport::Journey*>(_v) = _t->journey(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->reservationId(); break;
        case 9: *reinterpret_cast<QDateTime*>(_v) = _t->anchorTime(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->anchorTimeDelta(); break;
        case 11: *reinterpret_cast<QDateTime*>(_v) = _t->journeyTime(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isReachable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAlignment(*reinterpret_cast<enum Alignment*>(_v)); break;
        case 1: _t->setState(*reinterpret_cast<enum State*>(_v)); break;
        case 2: _t->setFloatingLocationType(*reinterpret_cast<enum FloatingLocationType*>(_v)); break;
        case 3: _t->setFrom(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 4: _t->setTo(*reinterpret_cast<KPublicTransport::Location*>(_v)); break;
        case 5: _t->setFromName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setToName(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setJourney(*reinterpret_cast<KPublicTransport::Journey*>(_v)); break;
        case 8: _t->setReservationId(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setAnchorTime(*reinterpret_cast<QDateTime*>(_v)); break;
        case 10: _t->setAnchorTimeDelta(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN15TransferDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferDerived::qt_create_metaobjectdata<qt_meta_tag_ZN15TransferDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferDerived, qt_meta_tag_ZN15TransferDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TransferDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<Transfer>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TransferDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TransferDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22TransferDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN22TransferDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferDerivedForeign",
        "QML.Element",
        "Transfer",
        "QML.Foreign",
        "TransferDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN22TransferDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN22TransferDerivedForeignE =
    TransferDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN22TransferDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN22TransferDerivedForeignE =
    qt_staticMetaObjectContent_ZN22TransferDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN22TransferDerivedForeignE =
    qt_staticMetaObjectContent_ZN22TransferDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject TransferDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN22TransferDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN22TransferDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN22TransferDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
