/****************************************************************************
** Meta object code from reading C++ file 'timelinedelegatecontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/timelinedelegatecontroller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinedelegatecontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26TimelineDelegateControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineDelegateController::qt_create_metaobjectdata<qt_meta_tag_ZN26TimelineDelegateControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineDelegateController",
        "QML.Element",
        "auto",
        "setupChanged",
        "",
        "batchIdChanged",
        "contentChanged",
        "currentChanged",
        "progressChanged",
        "journeyChanged",
        "previousLocationChanged",
        "connectionWarningChanged",
        "layoutChanged",
        "applyJourney",
        "QVariant",
        "journey",
        "includeFollowing",
        "arrivalMapArguments",
        "QJSValue",
        "departureMapArguments",
        "mapArguments",
        "addToCalendar",
        "KCalendarCore::Calendar*",
        "cal",
        "setVehicleLayout",
        "KPublicTransport::Stopover",
        "stopover",
        "arrival",
        "reservationManager",
        "ReservationManager*",
        "liveDataManager",
        "LiveDataManager*",
        "transferManager",
        "TransferManager*",
        "documentManager",
        "DocumentManager*",
        "tripGroupManager",
        "TripGroupManager*",
        "batchId",
        "isCurrent",
        "progress",
        "previousLocation",
        "departure",
        "KPublicTransport::JourneySection",
        "trip",
        "tripDepartureIndex",
        "qsizetype",
        "tripArrivalIndex",
        "startTime",
        "effectiveEndTime",
        "isLocationChange",
        "isPublicTransport",
        "journeyRequest",
        "KPublicTransport::JourneyRequest",
        "journeyDestinations",
        "QList<KPublicTransport::Location>",
        "connectionWarning",
        "isCanceled",
        "departurePlatformSections",
        "arrivalPlatformSections",
        "documentIds",
        "reservation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'batchIdChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'journeyChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousLocationChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectionWarningChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'applyJourney'
        QtMocHelpers::MethodData<void(const QVariant &, int)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'arrivalMapArguments'
        QtMocHelpers::MethodData<QJSValue() const>(17, 4, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'departureMapArguments'
        QtMocHelpers::MethodData<QJSValue() const>(19, 4, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'mapArguments'
        QtMocHelpers::MethodData<QJSValue() const>(20, 4, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'addToCalendar'
        QtMocHelpers::MethodData<void(KCalendarCore::Calendar *)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'setVehicleLayout'
        QtMocHelpers::MethodData<void(const KPublicTransport::Stopover &, bool)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::Bool, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'reservationManager'
        QtMocHelpers::PropertyData<ReservationManager*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'liveDataManager'
        QtMocHelpers::PropertyData<LiveDataManager*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'transferManager'
        QtMocHelpers::PropertyData<TransferManager*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'documentManager'
        QtMocHelpers::PropertyData<DocumentManager*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'tripGroupManager'
        QtMocHelpers::PropertyData<TripGroupManager*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'batchId'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isCurrent'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'progress'
        QtMocHelpers::PropertyData<float>(40, QMetaType::Float, QMC::DefaultPropertyFlags, 4),
        // property 'previousLocation'
        QtMocHelpers::PropertyData<QVariant>(41, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'arrival'
        QtMocHelpers::PropertyData<KPublicTransport::Stopover>(27, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'departure'
        QtMocHelpers::PropertyData<KPublicTransport::Stopover>(42, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'journey'
        QtMocHelpers::PropertyData<KPublicTransport::JourneySection>(15, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'trip'
        QtMocHelpers::PropertyData<KPublicTransport::JourneySection>(44, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'tripDepartureIndex'
        QtMocHelpers::PropertyData<qsizetype>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'tripArrivalIndex'
        QtMocHelpers::PropertyData<qsizetype>(47, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'startTime'
        QtMocHelpers::PropertyData<QDateTime>(48, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 5),
        // property 'effectiveEndTime'
        QtMocHelpers::PropertyData<QDateTime>(49, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 5),
        // property 'isLocationChange'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'isPublicTransport'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'journeyRequest'
        QtMocHelpers::PropertyData<KPublicTransport::JourneyRequest>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'journeyDestinations'
        QtMocHelpers::PropertyData<QList<KPublicTransport::Location>>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'connectionWarning'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'isCanceled'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'departurePlatformSections'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'arrivalPlatformSections'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'documentIds'
        QtMocHelpers::PropertyData<QStringList>(60, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'reservation'
        QtMocHelpers::PropertyData<QVariant>(61, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TimelineDelegateController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TimelineDelegateController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TimelineDelegateControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TimelineDelegateControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26TimelineDelegateControllerE_t>.metaTypes,
    nullptr
} };

void TimelineDelegateController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineDelegateController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupChanged(); break;
        case 1: _t->batchIdChanged(); break;
        case 2: _t->contentChanged(); break;
        case 3: _t->currentChanged(); break;
        case 4: _t->progressChanged(); break;
        case 5: _t->journeyChanged(); break;
        case 6: _t->previousLocationChanged(); break;
        case 7: _t->connectionWarningChanged(); break;
        case 8: _t->layoutChanged(); break;
        case 9: _t->applyJourney((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: { QJSValue _r = _t->arrivalMapArguments();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->departureMapArguments();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->mapArguments();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->addToCalendar((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Calendar*>>(_a[1]))); break;
        case 14: _t->setVehicleLayout((*reinterpret_cast<std::add_pointer_t<KPublicTransport::Stopover>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Calendar* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPublicTransport::Stopover >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::setupChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::batchIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::contentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::currentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::progressChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::journeyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::previousLocationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::connectionWarningChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDelegateController::*)()>(_a, &TimelineDelegateController::layoutChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 19:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::JourneyRequest >(); break;
        case 12:
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::JourneySection >(); break;
        case 10:
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Stopover >(); break;
        case 20:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KPublicTransport::Location> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ReservationManager**>(_v) = _t->reservationManager(); break;
        case 1: *reinterpret_cast<LiveDataManager**>(_v) = _t->liveDataManager(); break;
        case 2: *reinterpret_cast<TransferManager**>(_v) = _t->transferManager(); break;
        case 3: *reinterpret_cast<DocumentManager**>(_v) = _t->documentManager(); break;
        case 4: *reinterpret_cast<TripGroupManager**>(_v) = _t->m_tripGroupMgr; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->batchId(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isCurrent(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->progress(); break;
        case 8: *reinterpret_cast<QVariant*>(_v) = _t->previousLocation(); break;
        case 9: *reinterpret_cast<KPublicTransport::Stopover*>(_v) = _t->arrival(); break;
        case 10: *reinterpret_cast<KPublicTransport::Stopover*>(_v) = _t->departure(); break;
        case 11: *reinterpret_cast<KPublicTransport::JourneySection*>(_v) = _t->journey(); break;
        case 12: *reinterpret_cast<KPublicTransport::JourneySection*>(_v) = _t->trip(); break;
        case 13: *reinterpret_cast<qsizetype*>(_v) = _t->tripDepartureIndex(); break;
        case 14: *reinterpret_cast<qsizetype*>(_v) = _t->tripArrivalIndex(); break;
        case 15: *reinterpret_cast<QDateTime*>(_v) = _t->startTime(); break;
        case 16: *reinterpret_cast<QDateTime*>(_v) = _t->effectiveEndTime(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isLocationChange(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isPublicTransport(); break;
        case 19: *reinterpret_cast<KPublicTransport::JourneyRequest*>(_v) = _t->journeyRequest(); break;
        case 20: *reinterpret_cast<QList<KPublicTransport::Location>*>(_v) = _t->journeyDestinations(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->connectionWarning(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isCanceled(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->departurePlatformSections(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->arrivalPlatformSections(); break;
        case 25: *reinterpret_cast<QStringList*>(_v) = _t->documentIds(); break;
        case 26: *reinterpret_cast<QVariant*>(_v) = _t->reservation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setReservationManager(*reinterpret_cast<ReservationManager**>(_v)); break;
        case 1: _t->setLiveDataManager(*reinterpret_cast<LiveDataManager**>(_v)); break;
        case 2: _t->setTransferManager(*reinterpret_cast<TransferManager**>(_v)); break;
        case 3: _t->setDocumentManager(*reinterpret_cast<DocumentManager**>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_tripGroupMgr, *reinterpret_cast<TripGroupManager**>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        case 5: _t->setBatchId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TimelineDelegateController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineDelegateController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TimelineDelegateControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TimelineDelegateController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void TimelineDelegateController::setupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineDelegateController::batchIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineDelegateController::contentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TimelineDelegateController::currentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TimelineDelegateController::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TimelineDelegateController::journeyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TimelineDelegateController::previousLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TimelineDelegateController::connectionWarningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TimelineDelegateController::layoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
