/****************************************************************************
** Meta object code from reading C++ file 'qmlsingletons.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/qmlsingletons.h"
#include <QtNetwork/QSslError>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlsingletons.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5DummyE_t {};
} // unnamed namespace

template <> constexpr inline auto Dummy::qt_create_metaobjectdata<qt_meta_tag_ZN5DummyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dummy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Dummy, qt_meta_tag_ZN5DummyE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Dummy::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5DummyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5DummyE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5DummyE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26ReservationManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto ReservationManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN26ReservationManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReservationManagerInstance",
        "QML.Foreign",
        "ReservationManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<ReservationManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ReservationManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ReservationManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ReservationManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26ReservationManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23DocumentManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto DocumentManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN23DocumentManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DocumentManagerInstance",
        "QML.Foreign",
        "DocumentManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<DocumentManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DocumentManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DocumentManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23DocumentManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23DocumentManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29FavoriteLocationModelInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto FavoriteLocationModelInstance::qt_create_metaobjectdata<qt_meta_tag_ZN29FavoriteLocationModelInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FavoriteLocationModelInstance",
        "QML.Foreign",
        "FavoriteLocationModel",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<FavoriteLocationModelInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FavoriteLocationModelInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29FavoriteLocationModelInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29FavoriteLocationModelInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29FavoriteLocationModelInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21PkPassManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto PkPassManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN21PkPassManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PkPassManagerInstance",
        "QML.Foreign",
        "PkPassManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<PkPassManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PkPassManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PkPassManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21PkPassManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21PkPassManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16SettingsInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto SettingsInstance::qt_create_metaobjectdata<qt_meta_tag_ZN16SettingsInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SettingsInstance",
        "QML.Foreign",
        "Settings",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<SettingsInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SettingsInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SettingsInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SettingsInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SettingsInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23TransferManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto TransferManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN23TransferManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TransferManagerInstance",
        "QML.Foreign",
        "TransferManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<TransferManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TransferManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23TransferManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23TransferManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23TransferManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24TripGroupManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN24TripGroupManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupManagerInstance",
        "QML.Foreign",
        "TripGroupManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<TripGroupManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TripGroupManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TripGroupManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24TripGroupManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24TripGroupManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23LiveDataManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto LiveDataManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN23LiveDataManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LiveDataManagerInstance",
        "QML.Foreign",
        "LiveDataManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<LiveDataManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LiveDataManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23LiveDataManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23LiveDataManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23LiveDataManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26MapDownloadManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto MapDownloadManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN26MapDownloadManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MapDownloadManagerInstance",
        "QML.Foreign",
        "MapDownloadManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<MapDownloadManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MapDownloadManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26MapDownloadManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26MapDownloadManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26MapDownloadManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19PassManagerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto PassManagerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN19PassManagerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PassManagerInstance",
        "QML.Foreign",
        "PassManager",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<PassManagerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PassManagerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PassManagerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PassManagerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PassManagerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24ImportControllerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto ImportControllerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN24ImportControllerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImportControllerInstance",
        "QML.Foreign",
        "ImportController",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<ImportControllerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ImportControllerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ImportControllerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ImportControllerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ImportControllerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22TripGroupModelInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupModelInstance::qt_create_metaobjectdata<qt_meta_tag_ZN22TripGroupModelInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupModelInstance",
        "QML.Foreign",
        "TripGroupModel",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<TripGroupModelInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TripGroupModelInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TripGroupModelInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TripGroupModelInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22TripGroupModelInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29TraewellingControllerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto TraewellingControllerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN29TraewellingControllerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TraewellingControllerInstance",
        "QML.Foreign",
        "TraewellingController",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<TraewellingControllerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TraewellingControllerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29TraewellingControllerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29TraewellingControllerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29TraewellingControllerInstanceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN24MatrixControllerInstanceE_t {};
} // unnamed namespace

template <> constexpr inline auto MatrixControllerInstance::qt_create_metaobjectdata<qt_meta_tag_ZN24MatrixControllerInstanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MatrixControllerInstance",
        "QML.Foreign",
        "MatrixController",
        "QML.Singleton",
        "true",
        "QML.Element"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    2 },
    });
    return QtMocHelpers::metaObjectData<MatrixControllerInstance, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MatrixControllerInstance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24MatrixControllerInstanceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24MatrixControllerInstanceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24MatrixControllerInstanceE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
