/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<matrixbeacon.h>)
#  include <matrixbeacon.h>
#endif
#if __has_include(<matrixroomsmodel.h>)
#  include <matrixroomsmodel.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_itinerary_matrix()
{
    qmlRegisterModule("org.kde.itinerary.matrix", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ConnectionForeign>("org.kde.itinerary.matrix", 254);
    qmlRegisterTypesAndRevisions<KeyVerificationSessionForeign>("org.kde.itinerary.matrix", 254);
    qmlRegisterTypesAndRevisions<MatrixBeacon>("org.kde.itinerary.matrix", 254);
    qmlRegisterTypesAndRevisions<MatrixRoomsModel>("org.kde.itinerary.matrix", 254);
    qmlRegisterEnum<MatrixRoomsModel::EventRoles>("MatrixRoomsModel::EventRoles");
    qmlRegisterEnum<MatrixRoomsModel::RoomType>("MatrixRoomsModel::RoomType");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.itinerary.matrix", 254, 254);
}

static const QQmlModuleRegistration orgkdeitinerarymatrixRegistration("org.kde.itinerary.matrix", qml_register_types_org_kde_itinerary_matrix);
