/*
    SPDX-FileCopyrightText: 2020 Volker Krause <vkrause@kde.org>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef BUNDLE_CONSTANTS_H
#define BUNDLE_CONSTANTS_H

constexpr inline const char16_t BUNDLE_FAVORITE_LOCATION_DOMAIN[] = u"org.kde.itinerary/favorite-locations";
constexpr inline const char16_t BUNDLE_HEALTH_CERTIFICATE_DOMAIN[] = u"org.kde.itinerary/health-certificates";
constexpr inline const char16_t BUNDLE_LIVE_DATA_DOMAIN[] = u"org.kde.itinerary/live-data";
constexpr inline const char16_t BUNDLE_LOCATION_HISTORY_DOMAIN[] = u"org.kde.kpublictransport/location-history";
constexpr inline const char16_t BUNDLE_PASS_DOMAIN[] = u"org.kde.itinerary/programs";
constexpr inline const char16_t BUNDLE_PUBLIC_TRANSPORT_ASSET_DOMAIN[] = u"org.kde.kpublictransport/assets";
constexpr inline const char16_t BUNDLE_SETTINGS_DOMAIN[] = u"org.kde.itinerary/settings";
constexpr inline const char16_t BUNDLE_TRANSFER_DOMAIN[] = u"org.kde.itinerary/transfers";
constexpr inline const char16_t BUNDLE_TRIPGROUP_DOMAIN[] = u"org.kde.itinerary/trips";
constexpr inline const char16_t BUNDLE_VERSION_DOMAIN[] = u"org.kde.itinerary/version";

constexpr inline const auto BUNDLE_FORMAT_VERSION = 3;

#endif
