/****************************************************************************
** Meta object code from reading C++ file 'journeysectionmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/journeysectionmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journeysectionmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19JourneySectionModelE_t {};
} // unnamed namespace

template <> constexpr inline auto JourneySectionModel::qt_create_metaobjectdata<qt_meta_tag_ZN19JourneySectionModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JourneySectionModel",
        "QML.Element",
        "auto",
        "journeySectionChanged",
        "",
        "showProgressChanged",
        "progressChanged",
        "journeySection",
        "KPublicTransport::JourneySection",
        "departureProgress",
        "departed",
        "arrived",
        "showProgress",
        "sectionCount",
        "effectiveStopCount",
        "currentDateTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'journeySectionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProgressChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'journeySection'
        QtMocHelpers::PropertyData<KPublicTransport::JourneySection>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'departureProgress'
        QtMocHelpers::PropertyData<float>(9, QMetaType::Float, QMC::DefaultPropertyFlags, 2),
        // property 'departed'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'arrived'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'showProgress'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'sectionCount'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'effectiveStopCount'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'currentDateTime'
        QtMocHelpers::PropertyData<QDateTime>(15, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<JourneySectionModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JourneySectionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JourneySectionModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JourneySectionModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19JourneySectionModelE_t>.metaTypes,
    nullptr
} };

void JourneySectionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JourneySectionModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->journeySectionChanged(); break;
        case 1: _t->showProgressChanged(); break;
        case 2: _t->progressChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JourneySectionModel::*)()>(_a, &JourneySectionModel::journeySectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JourneySectionModel::*)()>(_a, &JourneySectionModel::showProgressChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JourneySectionModel::*)()>(_a, &JourneySectionModel::progressChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::JourneySection >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::JourneySection*>(_v) = _t->journeySection(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->departureProgress(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->departed(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->arrived(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_showProgress; break;
        case 5: *reinterpret_cast<int*>(_v) = _t->sectionCount(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->effectiveStopCount(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->currentDateTime(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setJourneySection(*reinterpret_cast<KPublicTransport::JourneySection*>(_v)); break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_showProgress, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->showProgressChanged();
            break;
        case 7: _t->setCurrentDateTime(*reinterpret_cast<QDateTime*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *JourneySectionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JourneySectionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19JourneySectionModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int JourneySectionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void JourneySectionModel::journeySectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void JourneySectionModel::showProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void JourneySectionModel::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
