/****************************************************************************
** Meta object code from reading C++ file 'locationinformation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/locationinformation.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'locationinformation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19LocationInformationE_t {};
} // unnamed namespace

template <> constexpr inline auto LocationInformation::qt_create_metaobjectdata<qt_meta_tag_ZN19LocationInformationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LocationInformation",
        "QML.Element",
        "locationInformation",
        "isoCode",
        "drivingSide",
        "KItinerary::KnowledgeDb::DrivingSide",
        "drivingSideDiffers",
        "drivingSideLabel",
        "powerPlugCompatibility",
        "PowerPlugCompatibility",
        "powerPlugTypes",
        "powerSocketTypes",
        "timeZoneDiffers",
        "timeZoneName",
        "timeZoneOffsetDelta",
        "currencyDiffers",
        "currencyCode",
        "dstDiffers",
        "isDst",
        "FullyCompatible",
        "PartiallyCompatible",
        "Incompatible"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isoCode'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'drivingSide'
        QtMocHelpers::PropertyData<KItinerary::KnowledgeDb::DrivingSide>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'drivingSideDiffers'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'drivingSideLabel'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'powerPlugCompatibility'
        QtMocHelpers::PropertyData<enum PowerPlugCompatibility>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'powerPlugTypes'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'powerSocketTypes'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'timeZoneDiffers'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'timeZoneName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'timeZoneOffsetDelta'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'currencyDiffers'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'currencyCode'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'dstDiffers'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isDst'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PowerPlugCompatibility'
        QtMocHelpers::EnumData<enum PowerPlugCompatibility>(9, 9, QMC::EnumFlags{}).add({
            {   19, PowerPlugCompatibility::FullyCompatible },
            {   20, PowerPlugCompatibility::PartiallyCompatible },
            {   21, PowerPlugCompatibility::Incompatible },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<LocationInformation, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN19LocationInformationE[] = {
    QMetaObject::SuperData::link<KItinerary::KnowledgeDb::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject LocationInformation::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LocationInformationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LocationInformationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN19LocationInformationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19LocationInformationE_t>.metaTypes,
    nullptr
} };

void LocationInformation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<LocationInformation *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KItinerary::KnowledgeDb::DrivingSide >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->isoCode(); break;
        case 1: *reinterpret_cast<KItinerary::KnowledgeDb::DrivingSide*>(_v) = _t->drivingSide(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->drivingSideDiffers(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->drivingSideLabel(); break;
        case 4: *reinterpret_cast<enum PowerPlugCompatibility*>(_v) = _t->powerPlugCompatibility(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->powerPlugTypes(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->powerSocketTypes(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->timeZoneDiffers(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->timeZoneName(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->timeZoneOffsetDelta(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->currencyDiffers(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->currencyCode(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->dstDiffers(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDst(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN26LocationInformationDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto LocationInformationDerived::qt_create_metaobjectdata<qt_meta_tag_ZN26LocationInformationDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LocationInformationDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LocationInformationDerived, qt_meta_tag_ZN26LocationInformationDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LocationInformationDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<LocationInformation>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LocationInformationDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LocationInformationDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26LocationInformationDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN33LocationInformationDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto LocationInformationDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN33LocationInformationDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LocationInformationDerivedForeign",
        "QML.Element",
        "LocationInformation",
        "QML.Foreign",
        "LocationInformationDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN33LocationInformationDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN33LocationInformationDerivedForeignE =
    LocationInformationDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN33LocationInformationDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN33LocationInformationDerivedForeignE =
    qt_staticMetaObjectContent_ZN33LocationInformationDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN33LocationInformationDerivedForeignE =
    qt_staticMetaObjectContent_ZN33LocationInformationDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject LocationInformationDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN33LocationInformationDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN33LocationInformationDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN33LocationInformationDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
