/****************************************************************************
** Meta object code from reading C++ file 'passmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/passmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'passmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PassManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PassManager::qt_create_metaobjectdata<qt_meta_tag_ZN11PassManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PassManager",
        "passChanged",
        "",
        "passId",
        "import",
        "QVariant",
        "pass",
        "id",
        "findMatchingPass",
        "update",
        "remove",
        "removeRow",
        "row",
        "QModelIndex",
        "parent",
        "removeRows",
        "count",
        "documentIds",
        "QVariantList",
        "Roles",
        "PassRole",
        "PassIdRole",
        "PassTypeRole",
        "PassDataRole",
        "NameRole",
        "ValidUntilRole",
        "StateRole",
        "ValidRangeLabelRole",
        "PassType",
        "ProgramMembership",
        "PkPass",
        "Ticket"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'passChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'import'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Method 'import'
        QtMocHelpers::MethodData<QString(const QVariant &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'findMatchingPass'
        QtMocHelpers::MethodData<QString(const QVariant &) const>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'pass'
        QtMocHelpers::MethodData<QVariant(const QString &) const>(6, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'update'
        QtMocHelpers::MethodData<void(const QString &, const QVariant &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 5, 6 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'removeRow'
        QtMocHelpers::MethodData<bool(int, const QModelIndex &)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'removeRow'
        QtMocHelpers::MethodData<bool(int)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'removeRows'
        QtMocHelpers::MethodData<bool(int, int, const QModelIndex &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 16 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'removeRows'
        QtMocHelpers::MethodData<bool(int, int)>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 16 },
        }}),
        // Method 'documentIds'
        QtMocHelpers::MethodData<QVariantList(const QVariant &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(19, 19, QMC::EnumFlags{}).add({
            {   20, Roles::PassRole },
            {   21, Roles::PassIdRole },
            {   22, Roles::PassTypeRole },
            {   23, Roles::PassDataRole },
            {   24, Roles::NameRole },
            {   25, Roles::ValidUntilRole },
            {   26, Roles::StateRole },
            {   27, Roles::ValidRangeLabelRole },
        }),
        // enum 'PassType'
        QtMocHelpers::EnumData<enum PassType>(28, 28, QMC::EnumFlags{}).add({
            {   29, PassType::ProgramMembership },
            {   30, PassType::PkPass },
            {   31, PassType::Ticket },
        }),
    };
    return QtMocHelpers::metaObjectData<PassManager, qt_meta_tag_ZN11PassManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PassManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PassManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PassManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PassManagerE_t>.metaTypes,
    nullptr
} };

void PassManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PassManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->passChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: { QString _r = _t->import((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->import((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->findMatchingPass((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariant _r = _t->pass((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->update((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 6: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->removeRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->removeRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->removeRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->removeRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantList _r = _t->documentIds((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PassManager::*)(const QString & )>(_a, &PassManager::passChanged, 0))
            return;
    }
}

const QMetaObject *PassManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PassManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PassManagerE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PassManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void PassManager::passChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
