/****************************************************************************
** Meta object code from reading C++ file 'timelineelement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/timelineelement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelineelement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TimelineElementE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineElement::qt_create_metaobjectdata<qt_meta_tag_ZN15TimelineElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineElement",
        "QML.Element",
        "timelineElement",
        "ElementType",
        "Undefined",
        "TodayMarker",
        "WeatherForecast",
        "LocationInfo",
        "Transfer",
        "Flight",
        "TrainTrip",
        "CarRental",
        "BusTrip",
        "BoatTrip",
        "Restaurant",
        "TouristAttraction",
        "Event",
        "Hotel",
        "RangeType",
        "SelfContained",
        "RangeBegin",
        "RangeEnd"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ElementType'
        QtMocHelpers::EnumData<enum ElementType>(3, 3, QMC::EnumFlags{}).add({
            {    4, ElementType::Undefined },
            {    5, ElementType::TodayMarker },
            {    6, ElementType::WeatherForecast },
            {    7, ElementType::LocationInfo },
            {    8, ElementType::Transfer },
            {    9, ElementType::Flight },
            {   10, ElementType::TrainTrip },
            {   11, ElementType::CarRental },
            {   12, ElementType::BusTrip },
            {   13, ElementType::BoatTrip },
            {   14, ElementType::Restaurant },
            {   15, ElementType::TouristAttraction },
            {   16, ElementType::Event },
            {   17, ElementType::Hotel },
        }),
        // enum 'RangeType'
        QtMocHelpers::EnumData<enum RangeType>(18, 18, QMC::EnumFlags{}).add({
            {   19, RangeType::SelfContained },
            {   20, RangeType::RangeBegin },
            {   21, RangeType::RangeEnd },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TimelineElement, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TimelineElement::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TimelineElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TimelineElementE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TimelineElementE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22TimelineElementDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineElementDerived::qt_create_metaobjectdata<qt_meta_tag_ZN22TimelineElementDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineElementDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineElementDerived, qt_meta_tag_ZN22TimelineElementDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineElementDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<TimelineElement>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TimelineElementDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TimelineElementDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22TimelineElementDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29TimelineElementDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineElementDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29TimelineElementDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineElementDerivedForeign",
        "QML.Element",
        "TimelineElement",
        "QML.Foreign",
        "TimelineElementDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN29TimelineElementDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN29TimelineElementDerivedForeignE =
    TimelineElementDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29TimelineElementDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN29TimelineElementDerivedForeignE =
    qt_staticMetaObjectContent_ZN29TimelineElementDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN29TimelineElementDerivedForeignE =
    qt_staticMetaObjectContent_ZN29TimelineElementDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject TimelineElementDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN29TimelineElementDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN29TimelineElementDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN29TimelineElementDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
