/****************************************************************************
** Meta object code from reading C++ file 'localizer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/localizer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'localizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9LocalizerE_t {};
} // unnamed namespace

template <> constexpr inline auto Localizer::qt_create_metaobjectdata<qt_meta_tag_ZN9LocalizerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Localizer",
        "formatAddress",
        "",
        "QVariant",
        "obj",
        "formatAddressWithContext",
        "otherObj",
        "homeCountryIsoCode",
        "formatCountryWithContext",
        "formatTime",
        "propertyName",
        "formatDate",
        "formatDateTime",
        "formatDateOrDateTimeLocal",
        "formatTimeZoneOffset",
        "seconds",
        "formatDuration",
        "formatSpeed",
        "km_per_hour",
        "KFormat::DistanceFormatOptions",
        "formatOpts",
        "formatWeight",
        "gram",
        "formatTemperatureRange",
        "minTemperature",
        "maxTemperature",
        "useFahrenheit",
        "formatAltitude",
        "altitude",
        "formatCurrency",
        "value",
        "isoCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'formatAddress'
        QtMocHelpers::MethodData<QString(const QVariant &) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'formatAddressWithContext'
        QtMocHelpers::MethodData<QString(const QVariant &, const QVariant &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 6 }, { QMetaType::QString, 7 },
        }}),
        // Method 'formatCountryWithContext'
        QtMocHelpers::MethodData<QString(const QVariant &, const QVariant &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 6 }, { QMetaType::QString, 7 },
        }}),
        // Method 'formatTime'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 10 },
        }}),
        // Method 'formatDate'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 10 },
        }}),
        // Method 'formatDateTime'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 10 },
        }}),
        // Method 'formatDateOrDateTimeLocal'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 10 },
        }}),
        // Method 'formatTimeZoneOffset'
        QtMocHelpers::MethodData<QString(qint64)>(14, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::LongLong, 15 },
        }}),
        // Method 'formatDuration'
        QtMocHelpers::MethodData<QString(int)>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 15 },
        }}),
        // Method 'formatSpeed'
        QtMocHelpers::MethodData<QString(double, KFormat::DistanceFormatOptions)>(17, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'formatWeight'
        QtMocHelpers::MethodData<QString(int)>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 22 },
        }}),
        // Method 'formatTemperatureRange'
        QtMocHelpers::MethodData<QString(double, double, bool)>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 24 }, { QMetaType::Double, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'formatAltitude'
        QtMocHelpers::MethodData<QString(double)>(27, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 28 },
        }}),
        // Method 'formatCurrency'
        QtMocHelpers::MethodData<QString(double, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 30 }, { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Localizer, qt_meta_tag_ZN9LocalizerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Localizer::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9LocalizerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9LocalizerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9LocalizerE_t>.metaTypes,
    nullptr
} };

void Localizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Localizer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->formatAddress((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->formatAddressWithContext((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->formatCountryWithContext((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->formatTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->formatDate((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->formatDateTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->formatDateOrDateTimeLocal((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->formatTimeZoneOffset((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->formatDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->formatSpeed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFormat::DistanceFormatOptions>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->formatWeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->formatTemperatureRange((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->formatAltitude((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->formatCurrency((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}
QT_WARNING_POP
