/****************************************************************************
** Meta object code from reading C++ file 'tripgroupmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/tripgroupmodel.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tripgroupmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14TripGroupModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupModel::qt_create_metaobjectdata<qt_meta_tag_ZN14TripGroupModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupModel",
        "currentBatchChanged",
        "",
        "adjacentTripGroups",
        "tripGroupId",
        "from",
        "to",
        "intersectingTripGroups",
        "intersectingXorAdjacentTripGroups",
        "emptyTripGroups",
        "currentTripGroupId",
        "locationAtTime",
        "QVariant",
        "dt",
        "currentBatchId",
        "currentOrNextRow",
        "Position",
        "Past",
        "Current",
        "Future"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentBatchChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'adjacentTripGroups'
        QtMocHelpers::MethodData<QStringList(const QString &) const>(3, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'adjacentTripGroups'
        QtMocHelpers::MethodData<QStringList(const QDateTime &, const QDateTime &) const>(3, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QDateTime, 5 }, { QMetaType::QDateTime, 6 },
        }}),
        // Method 'intersectingTripGroups'
        QtMocHelpers::MethodData<QStringList(const QDateTime &, const QDateTime &) const>(7, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QDateTime, 5 }, { QMetaType::QDateTime, 6 },
        }}),
        // Method 'intersectingXorAdjacentTripGroups'
        QtMocHelpers::MethodData<QStringList(const QDateTime &, const QDateTime &) const>(8, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QDateTime, 5 }, { QMetaType::QDateTime, 6 },
        }}),
        // Method 'emptyTripGroups'
        QtMocHelpers::MethodData<QStringList() const>(9, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'currentTripGroupId'
        QtMocHelpers::MethodData<QString() const>(10, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'locationAtTime'
        QtMocHelpers::MethodData<QVariant(const QDateTime &) const>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QDateTime, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentBatchId'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'currentOrNextRow'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Position'
        QtMocHelpers::EnumData<enum Position>(16, 16, QMC::EnumFlags{}).add({
            {   17, Position::Past },
            {   18, Position::Current },
            {   19, Position::Future },
        }),
    };
    return QtMocHelpers::metaObjectData<TripGroupModel, qt_meta_tag_ZN14TripGroupModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TripGroupModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TripGroupModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TripGroupModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TripGroupModelE_t>.metaTypes,
    nullptr
} };

void TripGroupModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TripGroupModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentBatchChanged(); break;
        case 1: { QStringList _r = _t->adjacentTripGroups((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QStringList _r = _t->adjacentTripGroups((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QStringList _r = _t->intersectingTripGroups((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->intersectingXorAdjacentTripGroups((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->emptyTripGroups();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->currentTripGroupId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariant _r = _t->locationAtTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TripGroupModel::*)()>(_a, &TripGroupModel::currentBatchChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentBatchId(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->currentOrNextRow(); break;
        default: break;
        }
    }
}

const QMetaObject *TripGroupModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TripGroupModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TripGroupModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int TripGroupModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TripGroupModel::currentBatchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
