/****************************************************************************
** Meta object code from reading C++ file 'reservationmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/reservationmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'reservationmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ReservationBatchE_t {};
} // unnamed namespace

template <> constexpr inline auto ReservationBatch::qt_create_metaobjectdata<qt_meta_tag_ZN16ReservationBatchE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReservationBatch",
        "elements",
        "startDateTime",
        "endDateTime"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'elements'
        QtMocHelpers::PropertyData<QStringList>(1, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'startDateTime'
        QtMocHelpers::PropertyData<QDateTime>(2, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'endDateTime'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReservationBatch, qt_meta_tag_ZN16ReservationBatchE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReservationBatch::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ReservationBatchE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ReservationBatchE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ReservationBatchE_t>.metaTypes,
    nullptr
} };

void ReservationBatch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ReservationBatch *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->m_resIds; break;
        case 1: *reinterpret_cast<QDateTime*>(_v) = _t->m_startDt; break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->m_endDt; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_resIds, *reinterpret_cast<QStringList*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_startDt, *reinterpret_cast<QDateTime*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_endDt, *reinterpret_cast<QDateTime*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN18ReservationManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ReservationManager::qt_create_metaobjectdata<qt_meta_tag_ZN18ReservationManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReservationManager",
        "reservationAdded",
        "",
        "id",
        "reservationChanged",
        "reservationRemoved",
        "batchAdded",
        "batchId",
        "batchChanged",
        "batchContentChanged",
        "batchRenamed",
        "oldBatchId",
        "newBatchId",
        "batchRemoved",
        "isEmpty",
        "reservation",
        "QVariant",
        "addReservation",
        "res",
        "resIdHint",
        "updateReservation",
        "resId",
        "removeReservation",
        "addReservationWithPostProcessing",
        "resData",
        "reservationsForBatch",
        "removeBatch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reservationAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'reservationChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'reservationRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'batchAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'batchChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'batchContentChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'batchRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'batchRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool() const>(14, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'reservation'
        QtMocHelpers::MethodData<QVariant(const QString &) const>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'addReservation'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 16, 18 }, { QMetaType::QString, 19 },
        }}),
        // Method 'addReservation'
        QtMocHelpers::MethodData<QString(const QVariant &)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 16, 18 },
        }}),
        // Method 'updateReservation'
        QtMocHelpers::MethodData<void(const QString &, QVariant)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { 0x80000000 | 16, 18 },
        }}),
        // Method 'removeReservation'
        QtMocHelpers::MethodData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'addReservationWithPostProcessing'
        QtMocHelpers::MethodData<QString(const QVariant &)>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 16, 24 },
        }}),
        // Method 'reservationsForBatch'
        QtMocHelpers::MethodData<QStringList(const QString &) const>(25, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'removeBatch'
        QtMocHelpers::MethodData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReservationManager, qt_meta_tag_ZN18ReservationManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReservationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ReservationManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ReservationManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ReservationManagerE_t>.metaTypes,
    nullptr
} };

void ReservationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReservationManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reservationAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->reservationChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->reservationRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->batchAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->batchChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->batchContentChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->batchRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->batchRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: { bool _r = _t->isEmpty();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariant _r = _t->reservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->addReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->addReservation((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->updateReservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 13: _t->removeReservation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: { QString _r = _t->addReservationWithPostProcessing((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QStringList _r = _t->reservationsForBatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->removeBatch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::reservationAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::reservationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::reservationRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::batchAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::batchChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::batchContentChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & , const QString & )>(_a, &ReservationManager::batchRenamed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReservationManager::*)(const QString & )>(_a, &ReservationManager::batchRemoved, 7))
            return;
    }
}

const QMetaObject *ReservationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReservationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ReservationManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ReservationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void ReservationManager::reservationAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ReservationManager::reservationChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ReservationManager::reservationRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ReservationManager::batchAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ReservationManager::batchChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ReservationManager::batchContentChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ReservationManager::batchRenamed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void ReservationManager::batchRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
