/****************************************************************************
** Meta object code from reading C++ file 'importcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/importcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'importcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ImportControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto ImportController::qt_create_metaobjectdata<qt_meta_tag_ZN16ImportControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImportController",
        "showImportPage",
        "",
        "infoMessage",
        "msg",
        "selectionChanged",
        "rowCountChanged",
        "enableAutoCommitChanged",
        "tripGroupChanged",
        "importFromUrl",
        "QUrl",
        "url",
        "importFromClipboard",
        "importData",
        "data",
        "fileName",
        "importText",
        "text",
        "importFromCalendar",
        "KCalendarCore::Calendar*",
        "calendar",
        "clear",
        "canAutoCommit",
        "hasSelection",
        "hasSelectedReservation",
        "selectedReservations",
        "QVariantList",
        "selectionBeginDateTime",
        "selectionEndDateTime",
        "count",
        "enableAutoCommit",
        "tripGroupName",
        "tripGroupId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showImportPage'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableAutoCommitChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tripGroupChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'importFromUrl'
        QtMocHelpers::MethodData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'importFromClipboard'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'importData'
        QtMocHelpers::MethodData<void(const QByteArray &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 14 }, { QMetaType::QString, 15 },
        }}),
        // Method 'importData'
        QtMocHelpers::MethodData<void(const QByteArray &)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QByteArray, 14 },
        }}),
        // Method 'importText'
        QtMocHelpers::MethodData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'importFromCalendar'
        QtMocHelpers::MethodData<void(KCalendarCore::Calendar *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'canAutoCommit'
        QtMocHelpers::MethodData<bool() const>(22, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasSelection'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'hasSelectedReservation'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'selectedReservations'
        QtMocHelpers::PropertyData<QVariantList>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'selectionBeginDateTime'
        QtMocHelpers::PropertyData<QDateTime>(27, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 2),
        // property 'selectionEndDateTime'
        QtMocHelpers::PropertyData<QDateTime>(28, QMetaType::QDateTime, QMC::DefaultPropertyFlags, 2),
        // property 'count'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'enableAutoCommit'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'tripGroupName'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'tripGroupId'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImportController, qt_meta_tag_ZN16ImportControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImportController::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ImportControllerE_t>.metaTypes,
    nullptr
} };

void ImportController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImportController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showImportPage(); break;
        case 1: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->selectionChanged(); break;
        case 3: _t->rowCountChanged(); break;
        case 4: _t->enableAutoCommitChanged(); break;
        case 5: _t->tripGroupChanged(); break;
        case 6: _t->importFromUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->importFromClipboard(); break;
        case 8: _t->importData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->importData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 10: _t->importText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->importFromCalendar((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Calendar*>>(_a[1]))); break;
        case 12: _t->clear(); break;
        case 13: { bool _r = _t->canAutoCommit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Calendar* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)()>(_a, &ImportController::showImportPage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)(const QString & )>(_a, &ImportController::infoMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)()>(_a, &ImportController::selectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)()>(_a, &ImportController::rowCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)()>(_a, &ImportController::enableAutoCommitChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImportController::*)()>(_a, &ImportController::tripGroupChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hasSelection(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasSelectedReservation(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->selectedReservations(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->selectionBeginDateTime(); break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->selectionEndDateTime(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_autoCommitEnabled; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->tripGroupName(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->tripGroupId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setAutoCommitEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setTripGroupName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setTripGroupId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ImportController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImportController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ImportControllerE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ImportController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ImportController::showImportPage()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImportController::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ImportController::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImportController::rowCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImportController::enableAutoCommitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImportController::tripGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
