/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<weatherforecast.h>)
#  include <weatherforecast.h>
#endif
#if __has_include(<weatherforecastmanager.h>)
#  include <weatherforecastmanager.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_itinerary_weather()
{
    qmlRegisterModule("org.kde.itinerary.weather", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<WeatherForecast>("org.kde.itinerary.weather", 254);
    qmlRegisterEnum<WeatherForecast::SymbolType>("WeatherForecast::SymbolType");
    qmlRegisterEnum<WeatherForecast::SymbolFlag>("WeatherForecast::SymbolFlag");
    qmlRegisterTypesAndRevisions<WeatherForecastManager>("org.kde.itinerary.weather", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.itinerary.weather", 254, 254);
}

static const QQmlModuleRegistration orgkdeitineraryweatherRegistration("org.kde.itinerary.weather", qml_register_types_org_kde_itinerary_weather);
